==> pynucastro-2.0.2.tar.gz: pynucastro-2.0.2/CITATION.md <==
If you use pynucastro, please CITE the "2.0" paper _and_ the latest
Zenodo DOI.  You can also cite the JOSS paper.


2.0 paper:

```
@ARTICLE{pynucastro2,
       author = {{Smith Clark}, Alexander and {Johnson}, Eric T. and {Chen}, Zhi and
                 {Eiden}, Kiran and {Willcox}, Donald E. and {Boyd}, Brendan and
                 {Cao}, Lyra and {DeGrendele}, Christopher J. and {Zingale}, Michael},
        title = "{pynucastro: A Python Library for Nuclear Astrophysics}",
      journal = {arXiv e-prints},
     keywords = {Astrophysics - Instrumentation and Methods for Astrophysics, Nuclear Experiment},
         year = 2022,
        month = oct,
          eid = {arXiv:2210.09965},
        pages = {arXiv:2210.09965},
archivePrefix = {arXiv},
       eprint = {2210.09965},
 primaryClass = {astro-ph.IM},
       adsurl = {https://ui.adsabs.harvard.edu/abs/2022arXiv221009965S},
      adsnote = {Provided by the SAO/NASA Astrophysics Data System}
}
```


JOSS:

```
@article{pynucastro,
   author = {{Willcox}, D.~E. and {Zingale}, M.},
    title = "{pynucastro: an interface to nuclear reaction rates and code generator for reaction network equations}",
  journal = {Journal of Open Source Software},
     year = 2018,
   volume = 3,
   number = 23,
   pages = 588,
     url = {https://doi.org/10.21105/joss.00588},
     doi = {10.21105/joss.00588},
 subject = {nuclear astrophysics}
}
```

Zenodo:

The latest version is always here:
https://doi.org/10.5281/zenodo.1202434

```
@software{the_pynucastro_development_2022_6802787,
  author       = {the pynucastro development and
                  Cao, Lyra and
                  Eiden, Kiran and
                  Johnson, Eric and
                  Li, Xinlong and
                  Smith Clark, Alexander and
                  Willcox, Donald and
                  Zingale, Michael},
  title        = {pynucastro/pynucastro:},
  month        = jul,
  year         = 2022,
  publisher    = {Zenodo},
  version      = {1.7.0},
  doi          = {10.5281/zenodo.6802787},
  url          = {https://doi.org/10.5281/zenodo.6802787}
}
```

==> pynucastro-2.0.3.tar.gz: pynucastro-2.0.3/CITATION.md <==
If you use pynucastro, please CITE the "2.0" paper _and_ the latest
Zenodo DOI.  You can also cite the JOSS paper.


2.0 paper:

```
@ARTICLE{pynucastro2,
       author = {{Smith Clark}, Alexander and {Johnson}, Eric T. and {Chen}, Zhi and
                 {Eiden}, Kiran and {Willcox}, Donald E. and {Boyd}, Brendan and
                 {Cao}, Lyra and {DeGrendele}, Christopher J. and {Zingale}, Michael},
        title = "{pynucastro: A Python Library for Nuclear Astrophysics}",
      journal = {arXiv e-prints},
     keywords = {Astrophysics - Instrumentation and Methods for Astrophysics, Nuclear Experiment},
         year = 2022,
        month = oct,
          eid = {arXiv:2210.09965},
        pages = {arXiv:2210.09965},
archivePrefix = {arXiv},
       eprint = {2210.09965},
 primaryClass = {astro-ph.IM},
       adsurl = {https://ui.adsabs.harvard.edu/abs/2022arXiv221009965S},
      adsnote = {Provided by the SAO/NASA Astrophysics Data System}
}
```


JOSS:

```
@article{pynucastro,
   author = {{Willcox}, D.~E. and {Zingale}, M.},
    title = "{pynucastro: an interface to nuclear reaction rates and code generator for reaction network equations}",
  journal = {Journal of Open Source Software},
     year = 2018,
   volume = 3,
   number = 23,
   pages = 588,
     url = {https://doi.org/10.21105/joss.00588},
     doi = {10.21105/joss.00588},
 subject = {nuclear astrophysics}
}
```

Zenodo:

The latest version is always here:
https://doi.org/10.5281/zenodo.1202434

```
@software{the_pynucastro_development_2022_7239007,
  author       = {the pynucastro development and
                  Boyd, Brendan and
                  Cao, Lyra and
                  Chen, Zhi and
                  Eiden, Kiran and
                  Johnson, Eric and
                  Li, Xinlong and
                  Smith Clark, Alexander and
                  Willcox, Donald and
                  Zingale, Michael},
  title        = {pynucastro/pynucastro: pynucastro 2.0.2},
  month        = oct,
  year         = 2022,
  publisher    = {Zenodo},
  version      = {2.0.2},
  doi          = {10.5281/zenodo.7239007},
  url          = {https://doi.org/10.5281/zenodo.7239007}
}
```
